@@ -4,22 +4,17 @@ package Business::Shipping::UPS_Online::Package;
 
 Business::Shipping::UPS_Online::Package
 
-=head1 VERSION
-
-$Rev: 157 $
-$Date: 2004-07-09 14:25:49 -0700 (Fri, 09 Jul 2004) $
-
 =head1 METHODS
 
 =over 4
 
 =cut
 
-$VERSION = do { my $r = q$Rev: 157 $; $r =~ /\d+/; $&; };
+use Any::Moose;
+use Business::Shipping::Package;
+use version; our $VERSION = qv('400');
 
-use strict;
-use warnings;
-use base ( 'Business::Shipping::Package' );
+extends 'Business::Shipping::Package';
 
 =item * packaging
 
@@ -50,13 +45,19 @@ UPS_Online-only attribute.
   UPS_Online-only attribute
  
 =cut
- 
-use Class::MethodMaker 2.0
-    [ 
-      new    => [ qw/ new / ],
-      new    => [ qw/ default_new / ],
-      scalar => [ 'packaging', 'signature_type', 'insured_currency_type', 'insured_value' ],
-    ];
+
+has 'packaging' => (
+    is      => 'rw',
+    isa     => 'Str',
+    default => '02',
+);
+
+has 'signature_type'        => (is => 'rw');
+has 'insured_currency_type' => (is => 'rw');
+has 'insured_value'         => (is => 'rw');
+
+# NOTE: Causes "Unsupported packaging requested." error.
+#__PACKAGE__->meta()->make_immutable();
 
 1;
 
@@ -66,12 +67,12 @@ __END__
 
 =head1 AUTHOR
 
-Dan Browning E<lt>F<db@kavod.com>E<gt>, Kavod Technologies, L<http://www.kavod.com>.
+Daniel Browning, db@kavod.com, L<http://www.kavod.com/>
 
 =head1 COPYRIGHT AND LICENCE
 
-Copyright (c) 2003-2004 Kavod Technologies, Dan Browning. All rights reserved.
-This program is free software; you may redistribute it and/or modify it under
-the same terms as Perl itself. See LICENSE for more info.
+Copyright 2003-2011 Daniel Browning <db@kavod.com>. All rights reserved.
+This program is free software; you may redistribute it and/or modify it 
+under the same terms as Perl itself. See LICENSE for more info.
 
 =cut
